//
//  ViewController.m
//  ex_NSNotificationCenter-deviceOrientation
//
//  Created by yoshiyuki oshige on 2013/09/15.
//  Copyright (c) 2013年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()

//ラベルをアウトレット接続してプロパティ宣言する
@property (weak, nonatomic) IBOutlet UILabel *label_A;
@property (weak, nonatomic) IBOutlet UILabel *label_B;
@property (weak, nonatomic) IBOutlet UILabel *label_C;
@property (weak, nonatomic) IBOutlet UILabel *label_D;

// 回転の通知を受けるメソッド
- (void)changedDeviceOrientation:(id)sender;
// ラベルを回転するメソッド
- (void) rotateLabels:(float)deg;
// ビューを回転するメソッド
- (void) rotateView:(UIView *)targetView degree:(float)deg;
@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// 通知センターにデバイス回転のオブザーバとして登録する
    NSNotificationCenter *center = [NSNotificationCenter defaultCenter];
    [center addObserver:self
               selector:@selector(changedDeviceOrientation:)
                   name:UIDeviceOrientationDidChangeNotification
                 object:nil];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

// デバイスの向きが変わったら通知される
- (void)changedDeviceOrientation:(id)sender {
    //デバイスを取得する
    UIDevice *device = [UIDevice currentDevice];
    //デバイスの向きで振り分ける
    switch (device.orientation) {
        case UIDeviceOrientationPortrait:// デバイスが正向き
            [self rotateLabels:0];// ラベルの回転を0 に戻す
            break;
        case UIDeviceOrientationPortraitUpsideDown:// デバイスが上下逆さま
            [self rotateLabels:180];// ラベルを上下逆さま
            break;
        case UIDeviceOrientationLandscapeLeft:// デバイスが左回転
            [self rotateLabels:90];// ラベルを右回転
            break;
        case UIDeviceOrientationLandscapeRight:// デバイスが右回転
            [self rotateLabels:-90];// ラベルを左回転
            break;
        default:
            NSLog(@"%ld", device.orientation);
            break;
    }
}

// 4個のラベルを回転させる
- (void) rotateLabels:(float)deg{
    [self rotateView:_label_A degree:deg];
    [self rotateView:_label_B degree:deg];
    [self rotateView:_label_C degree:deg];
    [self rotateView:_label_D degree:deg];
}

// 引数で指定したビューをアフィン変換で回転させる
- (void) rotateView:(UIView *)targetView degree:(float)deg{
    targetView.transform = CGAffineTransformMakeRotation(deg * M_PI/ 180.0);
}

@end
