//
//  ViewController.m
//  ex_CMMotionManager_accelerometer
//
//  Created by yoshiyuki oshige on 2013/09/16.
//  Copyright (c) 2013年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"
// CoreMotionフレームワークをインポートする
#import <CoreMotion/CoreMotion.h>

@interface ViewController ()
{
    //モーションマネージャ
    CMMotionManager *motionManager;
    //水平、垂直方向の速度
    double speedx;
    double speedy;
    //ビューの縦横、ボールの半径、跳ね返り係数
    double viewWidth;
    double viewHeight;
    double ballR;
    double haneK;
}

//ラベルとボールをアウトレット接続する
@property (weak, nonatomic) IBOutlet UILabel *myLabel;
@property (weak, nonatomic) IBOutlet UIImageView *ball;

//メソッド宣言
- (void)startAnimation;
- (void)animation:(CMAccelerometerData *)data;

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

// ビューが表示されたらアニメーションをスタートする
- (void)viewDidAppear:(BOOL)animated
{
    [self startAnimation];
}
// アニメーションのスタート
- (void)startAnimation {
    //速度の初期化
    speedx = 0;
    speedy = 0;
    // 画面の縦横サイズ
    viewWidth = self.view.bounds.size.width;
    viewHeight = self.view.bounds.size.height;
    ballR = _ball.bounds.size.height/2;
    //跳ね返り係数
    haneK = 0.6;
    
    // モーションマネージャを作る
    motionManager = [[CMMotionManager alloc] init];
    // 加速度センサーの計測インターバルの設定
    motionManager.accelerometerUpdateInterval = 0.006;// 60Hz
    // 定期的に実行するハンドラを設定
    CMAccelerometerHandler handler = ^(CMAccelerometerData *data, NSError *error){
        [self animation:data];
    };
    // 加速度センサーの利用を開始
    [motionManager startAccelerometerUpdatesToQueue:[NSOperationQueue currentQueue]
                                        withHandler:handler];
}

// 定期的に呼ばれてアニメーションを実行する
- (void)animation:(CMAccelerometerData *)data
{
    double time = data.timestamp;// 経過時間
    double accx = data.acceleration.x;// X 軸: 加速度G
    double accy = data.acceleration.y;// Y 軸: 加速度G
    // double accz = data.acceleration.z;// Z 軸: 加速度G
    
    // 加速度分だけ1回の移動距離を大きく（小さく）する
    speedx += accx;
    speedy += accy;
    // 移動後の座標
    double cx = _ball.center.x + speedx;
    double cy = _ball.center.y - speedy;
    
    // 横の壁で跳ね返る
    if((cx<ballR)&&(speedx<0)){
        cx = ballR;//左壁の位置に戻す
        speedx = -haneK * speedx;//速度の減衰と方向の逆転
    }else if((cx>(viewWidth - ballR))&&(speedx>0)){
        cx = viewWidth - ballR;//右壁の位置に戻す
        speedx = -haneK * speedx;//速度の減衰と方向の逆転
    }
    
    // 縦の壁で跳ね返る
    if((cy<ballR)&&(speedy>0)){
        cy = ballR;//上壁の位置に戻す
        speedy = -haneK * speedy;//速度の減衰と方向の逆転
    }else if((cy>(viewHeight - ballR))&&(speedy<0)){
        cy = viewHeight - ballR;//下壁の位置に戻す
        speedy = -haneK * speedy;//速度の減衰と方向の逆転
    }
    
    // ボールを動かす
    _ball.center = CGPointMake(cx, cy);

    // 経過時間
    _myLabel.text = [NSString stringWithFormat:@"%.2f", time];
}

@end
