//
//  ViewController.m
//  ex_CMMotionManager_deviceMotion
//
//  Created by yoshiyuki oshige on 2013/09/17.
//  Copyright (c) 2013年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"
//CoreMotion フレームワークをインポートする
#import <CoreMotion/CoreMotion.h>

@interface ViewController ()
{
    //モーションマネージャ
    CMMotionManager *motionManager;
}
// ラベルとUFO をアウトレット接続し、プロパティ宣言する
@property (weak, nonatomic) IBOutlet UILabel *myLabel;
@property (weak, nonatomic) IBOutlet UIImageView *ufo;

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    //UFOをビューの中央に表示する
    _ufo.center = self.view.center;
    // スタート
    [self startAnimation];
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

// アニメーションのスタート
- (void)startAnimation {
    // モーションマネージャを作る
    motionManager = [[CMMotionManager alloc] init];
    if(! motionManager.deviceMotionAvailable){
        return;
    }
    motionManager.deviceMotionUpdateInterval = 0.006;// 60Hz
    // ハンドラを指定
    CMDeviceMotionHandler handler = ^(CMDeviceMotion *motion, NSError *error){
        [self animation:motion];
    };
    // デバイスモーションの利用を開始する
    [motionManager startDeviceMotionUpdatesToQueue:[NSOperationQueue currentQueue]
                                       withHandler:handler];
}

// アニメーションの内容
- (void)animation:(CMDeviceMotion *)motion
{
    double time = motion.timestamp;// 経過時間
    double roll = motion.attitude.roll;// Y 軸回りの回転角度（ラジアン）
    double pitch = motion.attitude.pitch;// X 軸回りの回転角度（ラジアン）
    double yaw = motion.attitude.yaw;// Z 軸回りの回転角度（ラジアン）
    // デバイスの画面サイズに回転した比率を掛けて移動距離にする
    double width = self.view.bounds.size.width;
    double height = self.view.bounds.size.height;
    double cx = width * roll/M_PI;
    double cy = height * pitch/M_PI;
    
    /* ufo を動かす */
    // 回転トランスフォーム
    CGAffineTransform tf1 = CGAffineTransformMakeRotation(yaw);
    // 移動トランスフォーム
    CGAffineTransform tf2 = CGAffineTransformMakeTranslation(cx, cy);
    // トランスフォームの合成:
    _ufo.transform = CGAffineTransformConcat(tf1, tf2);
    // 経過時間
    _myLabel.text = [NSString stringWithFormat:@"%.2f", time];
}

@end
