//
//  ViewController.m
//  ex_CoreLocation
//
//  Created by yoshiyuki oshige on 2013/09/17.
//  Copyright (c) 2013年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()

//ラベルをアウトレット接続してプロパティ宣言する
@property (weak, nonatomic) IBOutlet UILabel *label_ido;
@property (weak, nonatomic) IBOutlet UILabel *label_keido;
@property (weak, nonatomic) IBOutlet UILabel *label_hyoukou;
@property (weak, nonatomic) IBOutlet UILabel *label_henkaku;
@property (weak, nonatomic) IBOutlet UILabel *label_deviceMuki;

//スイッチをアウトレット接続、アクション接続する
@property (weak, nonatomic) IBOutlet UISwitch *jihokuSwitch;
- (IBAction)changedJihokuSwitch:(UISwitch *)sender;

//磁針をアウトレット接続してプロパティ宣言する
@property (weak, nonatomic) IBOutlet UIImageView *jishin;

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    // サービス開始
    [self startLocationServices];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}



// ロケーションサービスを開始する
- (void) startLocationServices
{
    // ロケーションマネージャを作る
    if(! locationManager){
        // インスタンスを生成し、デリゲートを設定する
        locationManager = [[CLLocationManager alloc] init];
        locationManager.delegate = self;
    }
    /* 標準位置情報*/
    if ([CLLocationManager locationServicesEnabled]) {
        // 精度の設定
        locationManager.desiredAccuracy = kCLLocationAccuracyBest; // 数mの誤差精度
        // 更新距離（メートル）
        locationManager.distanceFilter = 3; // 3mごとに更新する
        // 標準位置情報の更新を開始する
        [locationManager startUpdatingLocation];
    }
    /* ヘディング（コンパス） */
    if ([CLLocationManager headingAvailable]) {
        // 磁北方向を指すかどうか
        isJihoku = NO;
        _jihokuSwitch.on = NO;
        
        // デバイスの基準の向き（真北にする向き）
        locationManager.headingOrientation = CLDeviceOrientationPortrait;
        // 更新角度（度）
        locationManager.headingFilter = 1;
        // ヘディングの更新を開始する
        [locationManager startUpdatingHeading];
    }
}

// 経度、緯度、標高を調べる
- (void)locationManager:(CLLocationManager *)manager didUpdateLocations:(NSArray *)locations
{
    // 最後のデータを取り出す
    CLLocation *locData = [locations lastObject];
    // 緯度（度）の表示
    _label_ido.text = [NSString stringWithFormat:@"%.3f", locData.coordinate.latitude];
    // 経度（度）の表示
    _label_keido.text = [NSString stringWithFormat:@"%.3f", locData.coordinate.longitude];
    // 標高（m）の表示
    _label_hyoukou.text = [NSString stringWithFormat:@"%.3f", locData.altitude];
}

// 真北、磁北を調べる
- (void)locationManager:(CLLocationManager *)manager didUpdateHeading:(CLHeading *)newHeading
{
    // デバイスが向いている方角（度）
    CLLocationDirection makita = newHeading.trueHeading;// 真北
    CLLocationDirection jihoku = newHeading.magneticHeading;// 磁北
    // 偏角
    _label_henkaku.text = [NSString stringWithFormat:@"%.1f", (makita - jihoku)];
    // 北の方角（度）
    CLLocationDirection kitaMuki;
    // 磁針の北を磁北向きにするか真北にするか選ぶ
    if(isJihoku){
        kitaMuki = jihoku;
    }else{
        kitaMuki = makita;
    }
    // 磁針を北に向ける
    _jishin.transform = CGAffineTransformMakeRotation(-kitaMuki * M_PI/180);
    // デバイスが向いている方角の表示
    _label_deviceMuki.text = [NSString stringWithFormat:@"%.1f", kitaMuki];
}

// 北の基準を磁北にするかどうかの切り替え
- (IBAction)changedJihokuSwitch:(UISwitch *)sender {
    isJihoku = sender.on;
}

@end
