//
//  ViewController.m
//  ex_MapKit
//
//  Created by yoshiyuki oshige on 2013/09/19.
//  Copyright (c) 2013年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()
{
    // 元のTintColor
    UIColor *defaltColor;
}

// マップビューのプロパティ宣言
@property (weak, nonatomic) IBOutlet MKMapView *myMapView;
// ツールバーのプロパティ宣言
@property (weak, nonatomic) IBOutlet UIToolbar *myToolbar;
// トラッキングボタンのプロパティ宣言
@property (weak, nonatomic) IBOutlet UIBarButtonItem *trackingButton;
// トラッキングボタンのメソッド宣言
- (IBAction)tapTrackingButton:(UIBarButtonItem *)sender;
//　マップタイプ切り替えボタンのメソッド宣言
- (IBAction)tapMapTypeSeg:(UISegmentedControl *)sender;
// Spotボタンのメソッド宣言
- (IBAction)tapSpotButton:(UIBarButtonItem *)sender;

@end


@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// _myMapViewのデリゲートになる
    _myMapView.delegate = self;
    // 現在地を表示する
    _myMapView.showsUserLocation = YES;
    // 元のTintColorを控えておく
    defaltColor = self.view.window.tintColor;
}


- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

// トラッキングボタンがタップされたので現在のトラッキングモードから次のモードに移行する
- (IBAction)tapTrackingButton:(UIBarButtonItem *)sender {
    // 現在のトラッキングモードで振り分ける
    switch (_myMapView.userTrackingMode) {
        case MKUserTrackingModeNone:
            // None から Follow へ
            [_myMapView setUserTrackingMode:MKUserTrackingModeFollow animated:YES];
            _trackingButton.image = [UIImage imageNamed:@"trackingFollow.png"];
            break;
        case MKUserTrackingModeFollow:
            // Follow から Heading へ
            [_myMapView setUserTrackingMode:MKUserTrackingModeFollowWithHeading animated:YES];
            _trackingButton.image = [UIImage imageNamed:@"trackingHeading.png"];
            break;
        case MKUserTrackingModeFollowWithHeading:
            // Heading から None へ
            [_myMapView setUserTrackingMode:MKUserTrackingModeNone animated:YES];
            _trackingButton.image = [UIImage imageNamed:@"trackingNone.png"];
            break;
        default:
            break;
    }
}


// セグメントボタンがタップされたのでマップタイプを変更する
/*
 書籍のコードにステータスバーの文字色を白にするコードが追加されています。
 Supporting Filesにあるinfo.plistで「View controller-based status bar」を追加し、NOに設定してあります。
 */
- (IBAction)tapMapTypeSeg:(UISegmentedControl *)sender {
    // 選択されたセグメントで振り分ける
    switch (sender.selectedSegmentIndex) {
        case 0:
            // 標準タイプに切り替える
            _myMapView.mapType = MKMapTypeStandard;
            // ツールバーのアルファを1に戻す
            _myToolbar.alpha = 1.0;
            // windowのtintColorを元に戻す
            self.view.window.tintColor = defaltColor;
            // ステータスバーの文字色を標準に戻す
            [[UIApplication sharedApplication] setStatusBarStyle:UIStatusBarStyleDefault];
            break;
        case 1:
            // サテライトタイプに切り替える
            _myMapView.mapType = MKMapTypeSatellite;
            // ツールバーが透けるようにする
            _myToolbar.alpha = 0.8;
            // windowのtintColorを白にする
            self.view.window.tintColor = [UIColor whiteColor];
            // ステータスバーの文字色を白にする
            [[UIApplication sharedApplication] setStatusBarStyle:UIStatusBarStyleLightContent];
            break;
        case 2:
            // ハイブリッドタイプに切り替える
            _myMapView.mapType = MKMapTypeHybrid;
            // ツールバーが透けるようにする
            _myToolbar.alpha = 0.8;
            // windowのtintColorを白にする
            self.view.window.tintColor = [UIColor whiteColor];
            // ステータスバーの文字色を白にする
            [[UIApplication sharedApplication] setStatusBarStyle:UIStatusBarStyleLightContent];
            break;
        default:
            break;
    }
}


// トラッキングモードが解除された
- (void)mapView:(MKMapView *)mapView didChangeUserTrackingMode:(MKUserTrackingMode)mode animated:(BOOL)animated
{
    // トラッキングボタンをNoneに戻す
    _trackingButton.image = [UIImage imageNamed:@"trackingNone.png"];
}

// 指定の座標（緯度、経度）に移動する
- (IBAction)tapSpotButton:(UIBarButtonItem *)sender {
    CLLocationDegrees latitude = 35.305267;// 緯度
    CLLocationDegrees longitude = 139.482358;// 経度
    // 緯度、経度から表示位置を求める
    CLLocationCoordinate2D center = CLLocationCoordinate2DMake(latitude, longitude);
    // 表示領域（中央、縦メートル、横メートル）
    MKCoordinateRegion theSpot = MKCoordinateRegionMakeWithDistance(center,1000,1000);
    // 指定の位置を表示する
    [_myMapView setRegion:theSpot animated:YES]; // YESのときアニメーションで指定座標に移動する
}

@end
