//
//  ViewController.m
//  ex_MapKit_search
//
//  Created by yoshiyuki oshige on 2013/09/19.
//  Copyright (c) 2013年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"
//　カスタムアノテーションクラス
#import "MyAnnotation.h"

@interface ViewController ()
{
    // 元のTintColor
    UIColor *defaltColor;
    // ピンを保管して使い回す
    MyAnnotation *myPin;
}

// マップビューのプロパティ宣言
@property (weak, nonatomic) IBOutlet MKMapView *myMapView;
// ツールバーのプロパティ宣言
@property (weak, nonatomic) IBOutlet UIToolbar *myToolbar;
// トラッキングボタンのプロパティ宣言
@property (weak, nonatomic) IBOutlet UIBarButtonItem *trackingButton;
// トラッキングボタンのメソッド宣言
- (IBAction)tapTrackingButton:(UIBarButtonItem *)sender;
//　マップタイプ切り替えボタンのメソッド宣言
- (IBAction)tapMapTypeSeg:(UISegmentedControl *)sender;
// Spotボタンのメソッド宣言
- (IBAction)tapSpotButton:(UIBarButtonItem *)sender;

/* 住所検索 */
// サーチバーのプロパティ宣言
@property (weak, nonatomic) IBOutlet UISearchBar *mySearchBar;

//　指定の緯度経度ポイントを表示する
- (void)gotoCoordinateIdo:(CLLocationDegrees)latitude keido:(CLLocationDegrees)longitude;

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// _myMapViewのデリゲートになる
    _myMapView.delegate = self;
    // サーチバーのデリゲートになる
    _mySearchBar.delegate = self;
    
    // 現在地を表示する
    _myMapView.showsUserLocation = YES;
}


- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


// トラッキングボタンがタップされたので現在のトラッキングモードから次のモードに移行する
- (IBAction)tapTrackingButton:(UIBarButtonItem *)sender {
    // 現在のトラッキングモードで振り分ける
    switch (_myMapView.userTrackingMode) {
        case MKUserTrackingModeNone:
            // None から Follow へ
            [_myMapView setUserTrackingMode:MKUserTrackingModeFollow animated:YES];
            _trackingButton.image = [UIImage imageNamed:@"trackingFollow.png"];
            break;
        case MKUserTrackingModeFollow:
            // Follow から Heading へ
            [_myMapView setUserTrackingMode:MKUserTrackingModeFollowWithHeading animated:YES];
            _trackingButton.image = [UIImage imageNamed:@"trackingHeading.png"];
            break;
        case MKUserTrackingModeFollowWithHeading:
            // Heading から None へ
            [_myMapView setUserTrackingMode:MKUserTrackingModeNone animated:YES];
            _trackingButton.image = [UIImage imageNamed:@"trackingNone.png"];
            break;
        default:
            break;
    }
}


// セグメントボタンがタップされたのでマップタイプを変更する
/*
 書籍のコードにステータスバーの文字色を白にするコードが追加されています。
 Supporting Filesにあるinfo.plistで「View controller-based status bar」を追加し、NOに設定してあります。
 */
- (IBAction)tapMapTypeSeg:(UISegmentedControl *)sender {
    // 選択されたセグメントで振り分ける
    switch (sender.selectedSegmentIndex) {
        case 0:
            // 標準タイプに切り替える
            _myMapView.mapType = MKMapTypeStandard;
            // ツールバーのアルファを1に戻す
            _myToolbar.alpha = 1.0;
            // windowのtintColorを元に戻す
            self.view.window.tintColor = defaltColor;
            // ステータスバーの文字色を標準に戻す
            [[UIApplication sharedApplication] setStatusBarStyle:UIStatusBarStyleDefault];
            break;
        case 1:
            // サテライトタイプに切り替える
            _myMapView.mapType = MKMapTypeSatellite;
            // ツールバーが透けるようにする
            _myToolbar.alpha = 0.8;
            // windowのtintColorを白にする
            self.view.window.tintColor = [UIColor whiteColor];
            // ステータスバーの文字色を白にする
            [[UIApplication sharedApplication] setStatusBarStyle:UIStatusBarStyleLightContent];
            break;
        case 2:
            // ハイブリッドタイプに切り替える
            _myMapView.mapType = MKMapTypeHybrid;
            // ツールバーが透けるようにする
            _myToolbar.alpha = 0.8;
            // windowのtintColorを白にする
            self.view.window.tintColor = [UIColor whiteColor];
            // ステータスバーの文字色を白にする
            [[UIApplication sharedApplication] setStatusBarStyle:UIStatusBarStyleLightContent];
            break;
        default:
            break;
    }
}


// トラッキングモードが解除された
- (void)mapView:(MKMapView *)mapView didChangeUserTrackingMode:(MKUserTrackingMode)mode animated:(BOOL)animated
{
    // トラッキングボタンをNoneに戻す
    _trackingButton.image = [UIImage imageNamed:@"trackingNone.png"];
}

// 指定の座標（緯度、経度）に移動する
- (IBAction)tapSpotButton:(UIBarButtonItem *)sender {
    CLLocationDegrees latitude = 35.305267;// 緯度
    CLLocationDegrees longitude = 139.482358;// 経度
    // 該当の地点へ移動する
    [self gotoCoordinateIdo:latitude keido:longitude];
}

/* UISearchBarDelegateメソッド */
// 検索モード開始
- (void)searchBarTextDidBeginEditing:(UISearchBar *)searchBar
{
    if(myPin){
        //ピンを取り除く
        [_myMapView removeAnnotation:myPin];
    }
}

// 検索モードキャンセル／終了
- (void)searchBarCancelButtonClicked:(UISearchBar *)searchBar
{
    //キーボードを下げる
    [searchBar resignFirstResponder];
    
}


// 検索の実行
- (void)searchBarSearchButtonClicked:(UISearchBar *)searchBar
{
    //キーボードを下げる
    [searchBar resignFirstResponder];
    // 正ジオコーディング
    CLGeocoder *geocoder = [[CLGeocoder alloc] init];
    [geocoder geocodeAddressString:(searchBar.text) inRegion:nil completionHandler:^(NSArray *placemarks, NSError *error){
        if(error){
            // エラーが発生している
            NSLog(@"エラー %@", error);
        } else {
            // 最初の場所
            CLPlacemark *place = placemarks[0];
            CLLocationDegrees latitude = place.location.coordinate.latitude; //緯度
            CLLocationDegrees longitude = place.location.coordinate.longitude; //経度
            // 該当の地点へ移動する
            [self gotoCoordinateIdo:latitude keido:longitude];
            
            NSString *placeName = place.addressDictionary[@"FormattedAddressLines"][0];
            // ピンを作る
            myPin = [[MyAnnotation alloc] initWithCoordinate:place.location.coordinate title:placeName];
            // ピンを刺す
            [_myMapView addAnnotation:myPin];
        }
    }];
}

//　指定の緯度経度ポイントを表示する
- (void)gotoCoordinateIdo:(CLLocationDegrees)latitude keido:(CLLocationDegrees)longitude {
    // 緯度、経度から表示位置を求める
    CLLocationCoordinate2D center = CLLocationCoordinate2DMake(latitude, longitude);
    // 表示領域（中央、縦メートル、横メートル）
    MKCoordinateRegion theSpot = MKCoordinateRegionMakeWithDistance(center,1000,1000);
    // 指定の位置を表示する
    [_myMapView setRegion:theSpot animated:YES]; // YESのときアニメーションで指定座標に移動する
}

//アノテーションが表示されるときに呼ばれる
- (MKAnnotationView *)mapView:(MKMapView *)mapView viewForAnnotation:(id < MKAnnotation >)annotation
{
    // 表示するアノテーションがCurrent Locationの場合はスルーする
    if([annotation.title isEqualToString:@"Current Location"]){
        return nil;
    }
    
    NSString *identifier = @"MyPin";
    // 識別子で刺したピンを参照する
    MKPinAnnotationView *pin = (MKPinAnnotationView *)[mapView dequeueReusableAnnotationViewWithIdentifier:identifier];
    // ピンがなければピンを作る
    if(pin == nil){
        pin = [[MKPinAnnotationView alloc] initWithAnnotation:annotation reuseIdentifier:identifier];
        pin.animatesDrop = YES;  // アニメーションをする
        pin.pinColor = MKPinAnnotationColorRed;  // 赤のピン
        pin.canShowCallout = YES;  // ピンタップ時にコールアウト（吹き出し）を表示する
    }
    return pin;
}

@end
