//
//  ViewController.m
//  ex_Camera
//
//  Created by yoshiyuki oshige on 2013/09/24.
//  Copyright (c) 2013年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"

// カメラとナビゲーションコントローラのデリゲートプロトコルを採用する
@interface ViewController () <UIImagePickerControllerDelegate, UINavigationControllerDelegate>

// 写真を表示するイメージビュー
@property (weak, nonatomic) IBOutlet UIImageView *myImageView;
// オリジナル画像を保存するかどうかのスイッチ
@property (weak, nonatomic) IBOutlet UISwitch *originalSaveSwitch;

// カメラの使用を開始する
- (IBAction)startCamera:(UIBarButtonItem *)sender;

@end



@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


// カメラの使用を開始する
- (IBAction)startCamera:(UIBarButtonItem *)sender
{
    // カメラを利用できるかどうかチェックする
    if([UIImagePickerController isSourceTypeAvailable:UIImagePickerControllerSourceTypeCamera])
    {
        // イメージピッカーコントローラを作る
        UIImagePickerController *imagePicker = [[UIImagePickerController alloc] init];
        //UIImagePickerControllerDelegate のデリゲートになる
        imagePicker.delegate = self;
        // カメラから画像を取り込む設定にする
        imagePicker.sourceType = UIImagePickerControllerSourceTypeCamera;
        imagePicker.allowsEditing = YES;//NO だとプレビューのみ
        
        // カメラを表示する
        [self presentViewController:imagePicker animated:YES completion:nil];
    }
}

//「Cancel」ボタンのデリゲートメソッド
- (void)imagePickerControllerDidCancel:(UIImagePickerController *)picker
{
    // 最初の画面に戻る
    [self dismissViewControllerAnimated:YES completion:nil];
}

//「Use Photo」ボタンのデリゲートメソッド
-(void) imagePickerController:(UIImagePickerController *)picker didFinishPickingMediaWithInfo:(NSDictionary *)info
{
    // オリジナル画像
    UIImage *originalImage = (UIImage *)[info objectForKey:UIImagePickerControllerOriginalImage];
    // 編集済み画像
    UIImage *editedImage = (UIImage *)[info objectForKey:UIImagePickerControllerEditedImage];
    // 最初の画面のイメージビューに編集済み画像を表示する
    _myImageView.image = editedImage;
    // 編集済み画像をカメラロールに保存する
    UIImageWriteToSavedPhotosAlbum(editedImage, nil, nil, nil);
    // オリジナル画像もカメラロールに保存するかどうか
    if(_originalSaveSwitch.on)
    {
        UIImageWriteToSavedPhotosAlbum(originalImage, nil, nil, nil);
    }
    // 最初の画面に戻る
    [self dismissViewControllerAnimated:YES completion:nil];
}


@end

